@@ -17,17 +17,13 @@
 #   along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 __all__ = [
-    "__name__",
     "__version__",
-    "YoutubeVideoMetadataDownloader"
+    "YouTubeVideoMetadataDownloader"
 ]
 
-from .lib.youtubevideometadatadownloader import (
-    YoutubeVideoMetadataDownloader
-)
+try:
+    from .lib.youtubevideometadatadownloader import YouTubeVideoMetadataDownloader
+except ImportError:
+    pass
 
-__name__ = "metatube"
-
-from ._version import get_versions
-__version__ = get_versions()['version']
-del get_versions
+__version__ = "1.0.3"
